@@ -103,7 +103,7 @@
 	  To compile a test program, compile cubature.c with
 	  -DTEST_INTEGRATOR as described at the end. */
 
-#include "cubature.h"
+#include <cubature.h>
 
 /* error return codes */
 #define SUCCESS 0
